<?php
// don't load directly
if ( ! defined( 'ABSPATH' ) ) {
	exit;
}

class SB_Autolink_List_Table extends WP_List_Table {


	public function __construct() {
		parent::__construct(
			array(
				'singular' => 'url',
				'plural'   => 'urls',
				'ajax'     => true,
			)
		);
	}


	/** Text displayed when no customer data is available */
	public function no_items() {
		_e( 'No keyword to links made.', 'seo-booster' );
	}

	/**
	 * @var array
	 *
	 * Array contains slug columns that you want hidden
	 *
	 */

	private $hidden_columns = array(
		'id',
	);


	protected function column_cb( $item ) {

		return sprintf(
			'<input type="checkbox" name="%1$s[]" value="%2$s" />',
			'alid',
			rawurlencode( $item['id'] )
		);
	}

	public function get_columns() {

		$columns = array(
			'cb'       => '<input type="checkbox" />',
			'keyword'  => _x( 'Keyword', 'Column label', 'seo-booster' ),
			'pointing' => '', // cannot call it arrow because of CSS clashes
			'url'      => _x( 'Target URL', 'Column label', 'seo-booster' ),
			'lastseen' => _x( 'Last used on', 'Column label', 'seo-booster' ),
		);

		return $columns;
	}

	protected function get_sortable_columns() {
		$sortable_columns = array(
			'keyword' => array( 'keyword', false ),
			'url'     => array( 'url', false ),
		);
		return $sortable_columns;
	}


	protected function column_default( $item, $column_name ) {
		switch ( $column_name ) {
			case 'keyword':
				return $item[ $column_name ];
			case 'url':
				return $item[ $column_name ];
			case 'pointing':
				return $item[ $column_name ];
			default:
				return print_r( $item, true ); // phpcs:ignore WordPress.PHP.DevelopmentFunctions.error_log_print_r
				// Show the whole array for troubleshooting purposes
		}
	}

	protected function column_pointing( $item ) {
		return '<span class="dashicons dashicons-arrow-right-alt"></span>';
	}

	protected function column_url( $item ) {

		$page = wp_unslash( $_REQUEST['page'] ); // phpcs:ignore WordPress.Security.NonceVerification.Recommended
		return sprintf(
			'<a href="%1$s" target="_blank">%2$s</a>',
			$item['url'],
			$item['url'],
			rawurlencode( $item['url'] )
		);
	}

	protected function column_lastseen( $item ) {

		$lastseen = maybe_unserialize( $item['lastseen'] );
		if ( ! is_array( $lastseen ) ) {
			return '';
		}
		$outstr = '';
		foreach ( $lastseen as $ls ) {
			$outstr .= '<span class="listitem"><a href="' . site_url( $ls ) . '" target="_blank">' . $ls . '</a>, </span>';
		}
		$outstr = rtrim( $outstr, ', </span>' );
		return $outstr;
	}


	protected function column_lp( $item ) {

		$page = wp_unslash( $_REQUEST['page'] ); // WordPress.Security.NonceVerification.Recommended

		// Build delete row action.
		$delete_query_args = array(
			'page'   => $page,
			'action' => 'delete',
			'alid'   => $item['id'],
		);
		$actions['delete'] = sprintf(
			'<a href="%1$s">%2$s</a>',
			esc_url( wp_nonce_url( add_query_arg( $delete_query_args, 'admin.php' ), 'deletelink_' . $item['id'] ) ),
			_x( 'Delete', 'List table row action', 'seo-booster' )
		);

		// Return the title contents.
		return sprintf(
			'<a href="%1$s" target="_blank">%2$s</a> <span style="color:silver;">(#%3$s)</span>%4$s',
			site_url( $item['lp'] ),
			$item['lp'],
			$item['id'],
			$this->row_actions( $actions )
		);
	}

	protected function get_bulk_actions() {

		$actions = array(
			'delete' => _x( 'Delete', 'List table bulk action', 'seo-booster' ),
		);
		return $actions;
	}



	protected function process_bulk_action() {

		if ( 'delete' === $this->current_action() ) {
			global $wpdb;
			if ( isset( $_GET['alid'] ) ) { // phpcs:ignore WordPress.Security.NonceVerification.Recommended
				if ( is_array( $_GET['alid'] ) ) { // phpcs:ignore WordPress.Security.NonceVerification.Recommended
					foreach ( $_GET['alid'] as $alid ) {
						$alid = intval( $alid ); // just to be sure
						$wpdb->query( "DELETE FROM {$wpdb->prefix}sb2_autolink WHERE id=$alid limit 1;" ); // @todo prepare
					}
				} else {
					$alid = intval( $_GET['alid'] );
					$wpdb->query( "DELETE FROM {$wpdb->prefix}sb2_autolink WHERE id=$alid limit 1;" ); // @todo prepare
				}
			}
		}
	}


	function prepare_items() {
		global $wpdb;
		$per_page = 50;
		$columns  = $this->get_columns();
		$hidden   = $this->hidden_columns;
		$sortable = $this->get_sortable_columns();

		$this->_column_headers = array( $columns, $hidden, $sortable );

		$this->process_bulk_action();

		$paged = ( isset( $_GET['paged'] ) ) ? $_GET['paged'] : 1;

		$offset = ( $paged * $per_page ) - $per_page;

		$search = ( isset( $_REQUEST['s'] ) ) ? sanitize_text_field( $_REQUEST['s'] ) : false;

		if ( $search ) {
			$do_search = $wpdb->prepare( ' AND (keyword LIKE %s OR url LIKE %s OR lastseen LIKE %s ) ', '%' . $wpdb->esc_like( $search ) . '%', '%' . $wpdb->esc_like( $search ) . '%', '%' . $wpdb->esc_like( $search ) . '%' );
		} else {
			$do_search = '';
		}

		$order = 'asc';
		if ( isset( $_GET['order'] ) ) { // phpcs:ignore WordPress.Security.NonceVerification.Recommended
			$order = sanitize_text_field( $_GET['order'] ); // phpcs:ignore WordPress.Security.NonceVerification.Recommended
		}

		$orderby = 'keyword';
		if ( isset( $_GET['orderby'] ) ) {
			$orderby = sanitize_text_field( $_GET['orderby'] );
		}

		$daquery = "SELECT id,
		keyword,
		url,
		lastseen
		FROM {$wpdb->prefix}sb2_autolink
		WHERE 1 = 1
		$do_search
		ORDER BY $orderby $order
		LIMIT $offset, $per_page;";

		$data = $wpdb->get_results( $daquery, ARRAY_A );

		$current_page = $this->get_pagenum();

		$total_items = $wpdb->get_var( "SELECT count(id) FROM {$wpdb->prefix}sb2_autolink WHERE 1=1 $do_search;" );

		$this->items = $data;

		$this->set_pagination_args(
			array(
				'total_items' => $total_items,
				'per_page'    => $per_page,
				'total_pages' => ceil( $total_items / $per_page ),
			)
		);
	}

	/**
	 * Callback to allow sorting of example data.
	 *
	 * @param string $a First value.
	 * @param string $b Second value.
	 *
	 * @return int
	 */
	protected function usort_reorder( $a, $b ) {
		$orderby = ! empty( $_REQUEST['orderby'] ) ? wp_unslash( $_REQUEST['orderby'] ) : 'lastcrawl';

		$order = ! empty( $_REQUEST['order'] ) ? wp_unslash( $_REQUEST['order'] ) : 'desc';

		$result = strcmp( $a[ $orderby ], $b[ $orderby ] );

		return ( 'asc' === $order ) ? $result : - $result;
	}
}
